Skip to contents

Retrieves selected information about touristic attractions in Colombia from the API Colombia. This function fetches the attraction ID, name, description, latitude, longitude, and city ID.

Usage

get_colombia_attractions()

Value

A tibble with the following columns:

  • id: Attraction identifier (integer)

  • name: Attraction name (character)

  • description: Attraction description (character)

  • latitude: Latitude coordinates (numeric)

  • longitude: Longitude coordinates (numeric)

  • cityId: City identifier (integer)

Returns NULL if the API request fails.

Details

This function sends a GET request to the API Colombia service. If the API request fails or returns an error status code, the function returns NULL with an informative message.

Note

Requires internet connection.

See also

Examples

if (interactive()) {
  get_colombia_attractions()
}