get_colombia_attractions: Get All Touristic Attractions of Colombia

View source: R/get_colombia_attractions.R

get_colombia_attractionsR Documentation

Get All Touristic Attractions of Colombia

Description

Retrieves selected information about touristic attractions in Colombia from the API Colombia. This function fetches the attraction ID, name, description, latitude, longitude, and city ID.

Usage

get_colombia_attractions()

Details

This function sends a GET request to the API Colombia service. If the API request fails or returns an error status code, the function returns NULL with an informative message.

Value

A tibble with the following columns:

  • id: Attraction identifier (integer)

  • name: Attraction name (character)

  • description: Attraction description (character)

  • latitude: Latitude coordinates (numeric)

  • longitude: Longitude coordinates (numeric)

  • cityId: City identifier (integer)

Returns NULL if the API request fails.

Note

Requires internet connection.

API Colombia: https://api-colombia.com/api/v1/TouristicAttraction

See Also

GET, fromJSON, tibble

Examples

if (interactive()) {
  get_colombia_attractions()
}


ColombiAPI documentation built on May 6, 2026, 9:07 a.m.